@@ -145,11 +145,11 @@ def read_pkg_file(self, file):
 
 
 def single_line(val):
-    # quick and dirty validation for description pypa/setuptools#1390
+    """Validate that the value does not have line breaks."""
+    # Ref: https://github.com/pypa/setuptools/issues/1390
     if '\n' in val:
-        # TODO after 2021-07-31: Replace with `raise ValueError("newlines not allowed")`
-        warnings.warn("newlines not allowed and will break in the future")
-        val = val.replace('\n', ' ')
+        raise ValueError('Newlines are not allowed')
+
     return val
 
 
@@ -289,7 +289,10 @@ def assert_bool(dist, attr, value):
         raise DistutilsSetupError(tmpl.format(attr=attr, value=value))
 
 
-def invalid(dist, attr, value):
+def invalid_unless_false(dist, attr, value):
+    if not value:
+        warnings.warn(f"{attr} is ignored.", DistDeprecationWarning)
+        return
     raise DistutilsSetupError(f"{attr} is invalid.")
 
 
